#
# spec file for package python-pyroute2
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pyroute2
Version:        0.5.10
Release:        3.3.1
Summary:        Python Netlink library
License:        GPL-2.0-or-later OR Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/svinota/pyroute2
Source:         https://files.pythonhosted.org/packages/source/p/pyroute2/pyroute2-%{version}.tar.gz
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Pyroute2 is a pure Python netlink library. It requires only Python stdlib, no
3rd party libraries. The library was started as an RTNL protocol
implementation, so the name is pyroute2, but now it supports many netlink
protocols. Some supported netlink families and protocols:

  * rtnl, network settings --- addresses, routes, traffic controls
  * nfnetlink --- netfilter API: ipset, nftables, ...
  * ipq --- simplest userspace packet filtering, iptables QUEUE target
  * devlink --- manage and monitor devlink-enabled hardware
  * generic --- generic netlink families
  * nl80211 --- wireless functions API (basic support)
  * taskstats --- extended process statistics
  * acpi_events --- ACPI events monitoring
  * thermal_events --- thermal events monitoring
  * VFS_DQUOT --- disk quota events monitoring

%prep
%setup -q -n pyroute2-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# tests require root access
#%%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} nosetests-%{$python_bin_suffix} -v

%files %{python_files}
%license README.license.md
%doc README.md CHANGELOG.md README.report.md
%license LICENSE.Apache.v2 LICENSE.GPL.v2
%{python_sitelib}/*
%python3_only %{_bindir}/ss2
%python3_only %{_bindir}/pyroute2-cli

%changelog
* Sat Mar 14 2020 dmueller@suse.com
- update to 0.5.10:
  * general: don't use pkg_resources <https://github.com/svinota/pyroute2/issues/677>
  * iproute: fix Windows support
  * netlink: provide the target field
  * ndb: use the target field from the netlink header
  * ndb: multiple SQL fixes, transactions fixed with the PostgreSQL backend
  * ndb: multiple object cache fixes <https://github.com/svinota/pyroute2/issues/683>
  * ndb.schema: drop DB triggers
  * ndb.objects: fix object management within a netns <https://github.com/svinota/pyroute2/issues/628>
  * ndb.objects.route: support route metrics
  * ndb.objects.route: fix default route syntax
* Fri Feb 28 2020 dmueller@suse.com
- update to 0.5.9:
  * ethtool: fix module setup
  * ethtool: initial support <https://github.com/svinota/pyroute2/pull/675>
  * tc: multimatch support <https://github.com/svinota/pyroute2/pull/674>
  * tc: meta support <https://github.com/svinota/pyroute2/pull/671>
  * tc: cake: add stats_app decoder <https://github.com/svinota/pyroute2/pull/662>
  * conntrack: filter <https://github.com/svinota/pyroute2/pull/660>
  * ndb.objects.interface: reload after setns
  * ndb.objects.route: create() dst syntax
  * ndb.objects.route: 'default' syntax
  * wireguard: basic testing
* Sat Feb  8 2020 mardnh@gmx.de
- Update to version 0.5.7:
  * ndb.objects.netns: prototype
  * ndb: netns management
  * ndb: netns sources autoconnect (disabled by default)
  * wireguard: basic support
  * netns: fix FD leakage
  * <https://github.com/svinota/pyroute2/issues/623>
  * cli: Python3 fixes
  * iproute: support `route('append', ...)`
  * ipdb: fix routes cleanup on link down
  * <https://github.com/svinota/pyroute2/issues/620>
  * wiset: support "mark" ipset type
* Mon Jun  3 2019 tchvatal@suse.com
- Update to 0.5.6:
  * ndb.objects.route: multipath routes
  * ndb.objects.rule: basic support
  * ndb.objects.interface: veth fixed
  * ndb.source: fix source restart
  * ndb.log: logging setup
* Fri Apr 12 2019 pgajdos@suse.com
- version update to 0.5.5
  * nftables: rules expressions
  * <https://github.com/svinota/pyroute2/pull/592>
  * netns: ns_pids
  * <https://github.com/svinota/pyroute2/pull/593>
  * ndb: wait() method
  * ndb: add extra logging, log state transitions
  * ndb: nested views, e.g. `ndb.interfaces['br0'].ports
  * cli: port pyroute2-cli to use NDB instead of IPDB
  * iproute: basic Windows support (proof of concept only)
  * remote: support mitogen proxy chains, support remote netns
* Mon Mar  4 2019 tchvatal@suse.com
- Update to 0.5.4:
  * iproute: basic SR-IOV support, virtual functions setup
  * ipdb: shutdown logging fixed
  * ipset: fix regression
  * netns: pushns() / popns() / dropns() calls
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Mon Nov 12 2018 jfunk@funktronics.ca
- update to 0.5.3:
  * bsd: parser improvements
  * ndb: PostgreSQL support
  * ndb: transactions commit/rollback
  * ndb: dependencies rollback
  * ipdb: IPv6 routes fix
  * <https://github.com/svinota/pyroute2/issues/543>
  * tcmsg: ematch support
  * tcmsg: flow filter
  * tcmsg: stats2 support improvements
  * ifinfmsg: GRE i/oflags, i/okey format fixed
  * <https://github.com/svinota/pyroute2/issues/531>
  * cli/ss2: improvements, tests
  * nlsocket: fix work on kernels < 3.2
  * <https://github.com/svinota/pyroute2/issues/526>
- changes from 0.5.2
  * ndb: read-only DB prototype
  * remote: support communication via stdio
  * general: fix async keyword -- Python 3.7 compatibility
  * <https://github.com/svinota/pyroute2/issues/467>
  * <https://bugzilla.redhat.com/show_bug.cgi?id=1583800>
  * iproute: support monitoring on BSD systems via PF_ROUTE
  * rtnl: support for SQL schema in message classes
  * nl80211: improvements
  * <https://github.com/svinota/pyroute2/issues/512>
  * <https://github.com/svinota/pyroute2/issues/514>
  * <https://github.com/svinota/pyroute2/issues/515>
  * netlink: support generators
- changes from 0.5.1
  * ipdb: #310 -- route keying fix
  * ipdb: #483, #484 -- callback internals change
  * ipdb: #499 -- eventloop interface
  * ipdb: #500 -- fix non-default :: routes
  * netns: #448 -- API change: setns() doesn't remove FD
  * netns: #504 -- fix resource leakage
  * bsd: initial commits
- changes from 0.5.0
  * ACHTUNG: ipdb commit logic is changed
  * ipdb: do not drop failed transactions
  * ipdb: #388 -- normalize IPv6 addresses
  * ipdb: #391 -- support both IPv4 and IPv6 default routes
  * ipdb: #392 -- fix MPLS route key reference
  * ipdb: #394 -- correctly work with route priorities
  * ipdb: #408 -- fix IPv6 routes in tables >= 256
  * ipdb: #416 -- fix VRF interfaces creation
  * ipset: multiple improvements
  * tuntap: #469 -- support s390x arch
  * nlsocket: #443 -- fix socket methods resolve order for Python2
  * netns: non-destructive `netns.create()`
* Tue Sep 19 2017 tbechtold@suse.com
- update to 0.4.21:
  * ipdb: #416 -- workaround for the vrf_table issue
  * ipdb: #392 -- fix MPLS route key reference
  * ipdb: #408 -- fix IPv6 routes in tables >= 256
  * ipdb: use tos as a route key
* Fri Aug 25 2017 tbechtold@suse.com
- update to 0.4.19:
  * ipdb: global methods `review()`, `drop()`, `dump()`, `load()`
  * ipdb: support VLAN protocol (802.1q, 802.1ad)
  * ipdb: initial support for IPv6 rules
  * ipdb: #388 -- normalize IPv6 addresses
  * ipdb: #391 -- support both IPv4 and IPv6 default routes
  * ipdb: #394 -- correctly work with route priorities
  * netns: non-destructive `netns.create()`
* Fri Aug 25 2017 tbechtold@suse.com
- update to 0.4.18:
  * ipdb: #379 [critical] -- routes in global commits
  * ipdb: #380 -- global commit with disabled plugins
  * ipdb: #381 -- exceptions fixed
  * ipdb: #382 -- manage dependent routes during interface commits
  * ipdb: #384 -- global `review()`
  * ipdb: #385 -- global `drop()`
  * netns: #383 -- support ppc64
  * general: public API refactored (same signatures; to be documented)
* Mon Jul 10 2017 tbechtold@suse.com
- update to 0.4.17:
  * req: #374 [critical] -- mode nla init
  * iproute: #378 [critical] -- fix `flush_routes()` to respect filters
  * ifinfmsg: #376 -- fix data plugins API to support pyinstaller
  * ipdb: race fixed: remove port/bridge
  * ipdb: #280 -- race fixed: port/bridge
  * ipdb: #302 -- ipaddr views: [ifname].ipaddr.ipv4, [ifname]ipaddr.ipv6
  * ipdb: #357 -- allow bridge timings to have some delta
  * ipdb: #338 -- allow to fix interface objects from failed `create()`
  * rtnl: #336 -- fix vlan flags
  * iproute: #342 -- the match method takes any callable
  * nlsocket: #367 -- increase default SO_SNDBUF
  * ifinfmsg: support tuntap on armv6l, armv7l platforms
- convert to singlespec
* Tue Jun 13 2017 dmueller@suse.com
- update to 0.4.15:
  * req: #365 -- full and short nla notation fixed, critical
  * iproute: #364 -- new method, `brport()`
  * ipdb: -- support bridge port options
  * event: new genl protocols set: VFS_DQUOT, acpi_event, thermal_event
  * ipdb: #310 -- fixed priority change on routes
  * ipdb: #349 -- fix setting ifalias on interfaces
  * ipdb: #353 -- mitigate kernel oops during bridge creation
  * ipdb: #354 -- allow to explicitly choose plugins to load
  * ipdb: #359 -- provide read-only context managers
  * rtnl: #336 -- vlan flags support
  * rtnl: #352 -- support interface type plugins
  * tc: #344 -- mirred action
  * tc: #346 -- connmark action
  * netlink: #358 -- memory optimization
  * config: #360 -- generic asyncio config
  * iproute: #362 -- allow to change or replace a qdisc
  * ipset: full rework of the IPSET_ATTR_DATA and IPSET_ATTR_ADT
    ACHTUNG: this commit may break API compatibility
  * ipset: hash:mac support
  * ipset: list:set support
  * ipdb: throw EEXIST when creates VLAN/VXLAN devs with same ID, but
    under different names
  * tests: #329 -- include unit tests into the bundle
  * legal: E/// logo removed
* Tue Jan 10 2017 dmueller@suse.com
- update to 0.4.12:
  * ipdb: #314 -- let users choose RTNL groups IPDB listens to
  * ipdb: #321 -- isolate `net_ns_.*` setup in a separate code block
  * ipdb: #322 -- IPv6 updates on interfaces in DOWN state
  * ifinfmsg: allow absolute/relative paths in the net_ns_fd NLA
  * ipset: #323 -- support setting counters on ipset add
  * ipset: `headers()` command
  * ipset: revisions
  * ipset: #326 -- mark types
* Mon Nov 21 2016 glin@suse.com
- Update to 0.4.11
  + rtnl: #284 -- support vlan_flags
  + ipdb: #288 -- do not inore link-local addresses
  + ipdb: #300 -- sort ip addresses
  + ipdb: #306 -- support net_ns_pid
  + ipdb: #307 -- fix IPv6 routes management
  + ipdb: #311 -- vlan interfaces address loading
  + iprsocket: #305 -- support NETLINK_LISTEN_ALL_NSID
  + devlink: fix fd leak on broken init
  + sock_diag: initial NETLINK_SOCK_DIAG support
  + rtnl: fix critical fd leak in the compat code
  + rtnl: compat proxying fix
  + rtnl: compat code is back
  + netns: custom netns path support
  + ipset: multiple improvements
* Tue Nov 15 2016 dmueller@suse.com
- update to 0.4.6:
  * ipdb: #278 -- fix initial ports mapping
  * ipset: #277 -- fix ADT attributes parsing
  * nl80211: #274, #275, #276 -- BSS-related fixes
* Mon Aug  8 2016 glin@suse.com
- Update Source url to pass the check in openSUSE:Factory
* Mon Aug  8 2016 glin@suse.com
- Update to 0.4.5
  + ifinfmsg: GTP interfaces support
  + generic: devlink protocol support
  + generic: code cleanup
  + iproute: #262 -- `get_vlans()` fix
  + iproute: default mask 32 for IPv4 in `addr()`
  + rtmsg: #260 -- RTA_FLOW support
  + ipdb: #259 -- critical `Interface` class fix
  + benchmark: initial release
  + ipdb: event modules
  + ipdb: on-demand views
  + ipdb: rules management
  + ipdb: bridge controls
  + ipdb: #258 -- important Python compatibility fixes
  + netns: #257 -- pipe leak fix
  + netlink: support pickling for nlmsg
  + netlink: no buffer copying in the parser
  + netlink: parse NLA on demand
  + ipdb: #244 -- lwtunnel multipath fixes
  + iproute: #235 -- route types
  + docs updated
* Sun May  8 2016 michael@stroeder.com
- Update to 0.4.0
* Fri Dec 11 2015 glin@suse.com
- Update to 0.3.15
* Fri Nov  6 2015 glin@suse.com
- initial import 0.3.14
